package
Version:
v0.1.1
Opens a new window with list of versions in this module.
Published: Dec 20, 2024
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
功能:app配置
说明:
功能:app配置-定义
说明:
功能:配置定义
说明:
const (
CONFIG_FOLDER = "config"
TOML_FILE_APP = "app.toml"
)
type ConfigApp struct {
Debug debug `toml:"debug"`
}
配置文件
Source Files
¶
Click to show internal directories.
Click to hide internal directories.